from src.fw_api import get_tracks
from src.fw_tags import list_tags
from src.fw_libraries import libraries
from src.mpv_control import play_track
from pyfzf.pyfzf import FzfPrompt
from loguru import logger
import time

fzf = FzfPrompt()


@logger.catch
def list_tracks(pg=None, search=None, tag=None, library=None):
    tracks = get_tracks(q=search, pg=pg, tag=tag, library=library)
    tracks_count = tracks.get('count')
    tracks_next = tracks.get('next')
    tracks_prev = tracks.get('previous')
    tracks_results = tracks.get('results')
    view = ['Search', 'Tags', 'Library', 'Play this page']
    if tracks_next:
        view.append('Play all pages')
        view.append('Next page')
    if tracks_prev:
        view.append('Prev page')

    for i in tracks_results:
        index = tracks_results.index(i)
        track_name = i.get('title')
        view.append(f'{index}.{track_name}')
    select = fzf.prompt(view, f'--header=\'Found {tracks_count} tracks\'')
    if select == []:
        return
    else:
        select = select[0].split('.', 1)[0]
    if select == 'Next page':
        list_tracks(pg=tracks_next)
    elif select == 'Prev page':
        list_tracks(pg=tracks_prev)
    elif select == 'Search':
        print('Search by track:')
        list_tracks(search=input())
    elif select == 'Tags':
        select_tag = list_tags()
        list_tracks(tag=select_tag)
    elif select == 'Library':
        select_lib = libraries()
        list_tracks(library=select_lib)
    elif select == 'Play this page':
        for i in tracks_results:
            play_track(track=i, multi=True)
    elif select == 'Play all pages':
        if tracks_count > 1000:
            yn = input('WARNING: you really want add more than 1000 tracks? (y/[n])\n').lower()
            if yn in ('', 'n'):
                return
        count_loaded = 0
        while tracks_count > count_loaded:
            for i in tracks_results:
                play_track(track=i, multi=True)
                count_loaded += 1
            time.sleep(0.2)
            tracks = get_tracks(pg=tracks_next)
            tracks_next = tracks.get('next')
            tracks_results = tracks.get('results')
    else:
        play_track(track=tracks_results[int(select)])
